<?php

namespace Litecms\Brand\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Brand\Models\ProductBrand;

class ProductBrandPolicy
{

    /**
     * Determine if the given user can view the product_brand.
     *
     * @param UserPolicy $user
     * @param ProductBrand $product_brand
     *
     * @return bool
     */
    public function view(UserPolicy $user, ProductBrand $product_brand)
    {
        if ($user->canDo('brand.product_brand.view') && $user->isAdmin()) {
            return true;
        }

        return $product_brand->user_id == user_id() && $product_brand->user_type == user_type();
    }

    /**
     * Determine if the given user can create a product_brand.
     *
     * @param UserPolicy $user
     * @param ProductBrand $product_brand
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('brand.product_brand.create');
    }

    /**
     * Determine if the given user can update the given product_brand.
     *
     * @param UserPolicy $user
     * @param ProductBrand $product_brand
     *
     * @return bool
     */
    public function update(UserPolicy $user, ProductBrand $product_brand)
    {
        if ($user->canDo('brand.product_brand.edit') && $user->isAdmin()) {
            return true;
        }

        return $product_brand->user_id == user_id() && $product_brand->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given product_brand.
     *
     * @param UserPolicy $user
     * @param ProductBrand $product_brand
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ProductBrand $product_brand)
    {
        return $product_brand->user_id == user_id() && $product_brand->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given product_brand.
     *
     * @param UserPolicy $user
     * @param ProductBrand $product_brand
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ProductBrand $product_brand)
    {
        if ($user->canDo('brand.product_brand.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given product_brand.
     *
     * @param UserPolicy $user
     * @param ProductBrand $product_brand
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ProductBrand $product_brand)
    {
        if ($user->canDo('brand.product_brand.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
